our $VERSION = '0.42';

=head1 NAME

Hello - Hello World!

=head1 SYNOPSIS

  my $hey = Hello->new;

  say $hey->sup
      if 1;

=head1 DESCRIPTION

Hello, this is the description.

=head2 Interface

This is all about the interface.

=head3 C<new>

Gotta cover the C<new()> method.

=head1 SEE ALSO

=over

=item * L<Heya::Man>

=item * L<Test::XPath>

=item * L<Foo::Bar/NAME>

=item * L</DESCRIPTION>

=back

=head1 AUTHOR

Someone Else

=head1 COPYRIGHT

Copyright (c) Someone Else 2009, some rights reserved.

This module is free software; you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut
