=head1 NAME

Heya::Man - Hey man, wassup?

=head1 SYNOPSIS

  my $man = Heya::Man->init;

=head1 DESCRIPTION

Heya man, this is the description.

=head2 Interface

This is all about the interface.

=head3 C<init>

Gotta cover the C<init()> method.

=head1 AUTHOR

Someone Else

=head1 COPYRIGHT

Copyright (c) Someone Else 2009, some rights reserved.

This module is free software; you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut

