body {
    margin: 0;
    padding: 0;
    *padding: 20px; /* Fix for IE6/7 */
    background-color: #FFF;
    font-family: trebuchet ms, verdana, tahoma, helvetica, arial;
    font-size: 90%;
    line-height: 150%;
}

body > #nav {
  position: fixed;
  font-size: 95%;
}

#nav {
  position: absolute;
  top: 0;
  left: 0;
  width: 200px;
  height: 100%;
  overflow: auto;
  color: white;
  background-color: #555;
  white-space: nowrap;
  border-left: 1px solid black;
}
#nav > ul, #nav h3 {
    padding-left: 10px;
}
#nav li {
  cursor: pointer;
  border-top: 1px solid transparent;
  border-bottom: 1px solid transparent;
  line-height: 140%;
}
#nav li a:hover, #nav .sel {
  border-top: 1px solid white;
  border-bottom: 1px solid white;
  background: #444;
}
#nav span {
  width: 1.4em;
  float: left;
  text-align: center;
}

#nav a {
  color: white;
  text-decoration: none;
  display: block;
  border-top: 1px solid transparent;
  border-bottom: 1px solid transparent;
}

#doc {
   padding-left: 200px;
   margin: 0;
}

#doc > * {
  margin-left: 20px;
  margin-right: 20px;
}
#doc code {
  font-size: 120%;
}

#doc pre {
  line-height: 170%;
  background-color: #ddb;
  padding: .5em;
  border: 1px dashed #555;
  overflow: auto;
}

#doc ul, #doc ol {
  list-style-position: inside;
  padding-left: 1em;
  margin-bottom: 0;
}
#doc li {
  text-indent: -1em;
}
#doc li p {
   text-indent: 0;
}
#doc h1, #doc h2 {
  font-family: helvetica, arial, sans-serif;
  font-weight: 100;
  text-align: right;
}
#doc h1 {
  border-bottom: 1px solid #808080;
  letter-spacing: 4px;
  font-size: 250%;
}
#doc h2 {
  border-bottom: 1px dashed #808080;
  letter-spacing: 3px;
  font-size: 150%;
}
#doc h3, #doc h4, #doc h5, #doc h6 {
  font-family: helvetica, arial, sans-serif;
  margin-bottom: 0;
}
#doc p { margin-top: 0 }
#tree, #tree ul {
  list-style : none;
  margin: 0;
  padding: 0;
  border: 0;
}

#tree ul {
  margin-left: 15px;
}

#tree li.open ul {
  display:block;
}
#tree li.closed ul {
  display:none !important;
}

#index ul {
  padding-left: 2em;
}

#doc .oops {
  color: red;
}

/* IE6 specific overrides */

* html #nav li {
  border-top: 1px solid #555;
  border-bottom: 1px solid #555;
}
* html #nav a {
  border-top: 1px solid #555;
  border-bottom: 1px solid #555;
}
* html #nav {
	clear: both;
}
