=head1 NAME

Foo::Bar::Baz - Bazzle your Bar, Foo!

=head1 SYNOPSIS

  my $baz = Foo::Bar::Baz->new;

=head1 DESCRIPTION

This is the description. Blah blah blah. It's all about the Bazzle.

=head2 Interface

This is all about the Baz interface.

=head3 C<new>

Gotta cover the C<new()> method.

=head1 AUTHOR

Someone Else

=head1 COPYRIGHT

Copyright (c) Someone Else 2009, some rights reserved.

This module is free software; you can redistribute it and/or modify it under
the same terms as Perl itself.

=cut

package Foo::Bar::Baz;

our $VERSION = '0.41';
